//importing files for the data
import {select, 
        csv,
        extent,
        scaleLinear,
        axisLeft,
        curveBasis,
        axisBottom,
        scaleTime,
        line} from "d3";

const svg = select("svg");

const width= +svg.attr("width");
const height= +svg.attr("height");

//Determining the x and y axis data
const xValue=  d=> d.timestamp;
const yValue= d=> d.temperature;
const margin = {top: 80, right: 10, bottom: 70, left: 80};
const innerWidth = width- (margin.left+ margin.right);
const innerHeight = height- (margin.top+ margin.bottom);

////rendering the data into visual data line
const render=data => {
  const xScale = scaleTime()
  							.domain(extent(data, xValue))
  							.range([0, innerWidth])
  							.nice();
  
  const yScale = scaleLinear()
  							 .domain(extent(data, yValue))
  							 .range([ innerHeight, 0])
    					   .nice();
 
   const xAxis= axisBottom(xScale)
  							.tickSize(-innerHeight)
  							.tickPadding("10");
   const yAxis = axisLeft(yScale)
   							.tickSize(-innerWidth)
  							.tickPadding("10");  
  
  const g = svg.append("g")
  					.attr("transform" , `translate(${margin.left}, ${margin.top})`);
const yAxisGroup= g.append("g").call(yAxis);
        yAxisGroup.selectAll(".domain").remove();
  	
  
 			 g.append("text"). text( "Weather conditions in Belgium")
    							.attr("x", -innerWidth/50).attr("y", "-40").attr("class", "title");
  
 const xAxisGroup= g.append("g").call(xAxis) 
           			.attr("transform" , `translate(0, ${innerHeight})`);
  		 xAxisGroup.append("text").text("Months")
    						.attr("x", innerWidth/2).attr("y",margin.bottom/1.2)
  							.attr("class", "xLabel");
  	yAxisGroup.append('text')
      .attr('class', 'yLabel')
      .attr('y', "-50")
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text("Temperature");
  
  //Line generating on the scale 
  const lineGenerator = line()
  												.x(d=> xScale(xValue(d)) )
  												.y(d=> yScale(yValue(d)) )
  												.curve(curveBasis);
  g.append('path')
  	.attr('class', 'path')
  	.attr("stroke", "black")
  	.attr('d',lineGenerator(data));
};

//Data retrived from the dataset
csv("https://gist.githubusercontent.com/vdvoorder/839ca31d5ec82e9160ee76fcb6799885/raw/daily-atmospheric-conditions_belgium_2021.csv").then(data => {
  data.forEach(d => {
    d.temperature= +d.air_temperature_avg;
    d.timestamp = new Date(d.date);
  });
  render(data);
});
